@@ -77,7 +77,7 @@ FSelectInstanceSingleCrit = R6Class("FSelectInstanceSingleCrit",
       super$initialize(obj, obj$domain, terminator)
 
       self$archive = ArchiveFSelect$new(search_space = self$objective$domain,
-        codomain = self$objective$codomain)
+        codomain = self$objective$codomain, check_values = check_values)
       self$objective$archive = self$archive
 
       private$.objective_function = objective_function
